@@ -1,8 +1,7 @@
 #! /bin/bash
 
 ##########################################################
-# Run all non-evosuite unit tests, which is the 
-# default option. 
+# Run tests. 
 ##########################################################
 
 echo "EMBOSS_ROOT set to: "$EMBOSS_ROOT
@@ -10,5 +9,5 @@ echo
 
 cd ..
 
-mvn test
+mvn -DEMBOSS_ROOT=${EMBOSS_ROOT} test
 
